@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53;
 BEGIN {
-  $Net::Amazon::Route53::VERSION = '0.113490';
+  $Net::Amazon::Route53::VERSION = '0.113630';
 }
 use LWP::UserAgent;
 use HTTP::Request;
@@ -481,7 +481,7 @@ sub _get_change_xml {
                   %s
                </ResourceRecords>
             </ResourceRecordSet>
-         </Change>
+        </Change>
         <Change>
             <Action>CREATE</Action>
             <ResourceRecordSet>
@@ -492,11 +492,11 @@ sub _get_change_xml {
                   %s
                </ResourceRecords>
             </ResourceRecordSet>
-         </Change>
+        </Change>
 ENDXML
 
     my $change_xml = sprintf($change_xml_str,
-        (map {$_} ($record->type, $record->name, $record->type, $record->ttl,)),
+        (map {$_} ($record->name, $record->type, $record->ttl,)),
         join("\n", map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"} @{ $record->original_values }),
         (map {$_} ($record->name, $record->type, $record->ttl,)),
         join("\n", map {"<ResourceRecord><Value>" . $_ . "</Value></ResourceRecord>"} @{ $record->values }));
@@ -548,6 +548,11 @@ L<http://docs.amazonwebservices.com/Route53/latest/APIReference/>
 
 Marco FONTANI <mfontani@cpan.org>
 
+=head1 CONTRIBUTORS
+
+Daiji Hirata <hirata@uva.ne.jp>
+Amiri Barksdale <amiri@arisdottle.net>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Marco FONTANI.
